Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1088)

Unified Diff: pkg/analyzer_cli/lib/src/driver.dart

Issue 1830463002: Change analyzer_cli's "package mode" into a "build mode". (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer_cli/lib/src/driver.dart
diff --git a/pkg/analyzer_cli/lib/src/driver.dart b/pkg/analyzer_cli/lib/src/driver.dart
index eb1df03926c0f9552ab2a11ea80a0d64f631708a..b352abab876ef049189fafff9873fa30274f8d83 100644
--- a/pkg/analyzer_cli/lib/src/driver.dart
+++ b/pkg/analyzer_cli/lib/src/driver.dart
@@ -124,8 +124,8 @@ class Driver implements CommandLineStarter {
_setupEnv(options);
// Do analysis.
- if (options.packageMode) {
- ErrorSeverity severity = _analyzePackage(options);
+ if (options.buildMode) {
+ ErrorSeverity severity = _buildModeAnalyze(options);
// In case of error propagate exit code.
if (severity == ErrorSeverity.ERROR) {
exitCode = severity.ordinal;
@@ -241,10 +241,10 @@ class Driver implements CommandLineStarter {
return allResult;
}
- /// Perform package analysis according to the given [options].
- ErrorSeverity _analyzePackage(CommandLineOptions options) {
+ /// Perform analysis in build mode according to the given [options].
+ ErrorSeverity _buildModeAnalyze(CommandLineOptions options) {
return _analyzeAllTag.makeCurrentWhile(() {
- return new PackageAnalyzer(options, stats).analyze();
+ return new BuildMode(options, stats).analyze();
});
}

Powered by Google App Engine
This is Rietveld 408576698